@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_sunos5_8.h,v 1.2.2.6 2005/01/03 20:56:13 ezk Exp $
+ * $Id$
  *
  */
 
@@ -103,6 +102,11 @@
 #define	NFSPROC_READDIR ((unsigned long)(16))
 #define	NFSPROC_STATFS ((unsigned long)(17))
 
+#define AUTOFS_CONFTYPE "ticotsord"
+
+#ifndef INADDR_NONE
+# define INADDR_NONE ((unsigned long) -1)
+#endif /* INADDR_NONE */
 
 /*
  * TYPEDEFS:
